=======
History
=======

0.2.7 (2019-02-23)
------------------

* Cross-platform: Windows, Mac, and Linux are officially supported.

* Works with Python 2.7, 3.4, 3.5, 3.6, and PyPy.

* Supports RESTful APIs over mongodb datasource using Python Eve.

* Supports JSON-RPC APIs using jsonrpcserver. 


0.1.0 (2019-02-18)
------------------

* First release on PyPI.
